Array API Standard Support: ``differentiate``
=============================================

.. _array_api_support_differentiate_cpu:

Support on CPU
--------------

.. array-api-support-per-function::
    :module: differentiate
    :backend_type: cpu

.. _array_api_support_differentiate_gpu:

Support on GPU
--------------

.. array-api-support-per-function::
    :module: differentiate
    :backend_type: gpu

.. _array_api_support_differentiate_jit:

Support with JIT
----------------

.. array-api-support-per-function::
    :module: differentiate
    :backend_type: jit
